"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const child_process_1 = require("child_process");
const fs = require("fs");
const fse = require("fs-extra");
const path = require("path");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('sfdx-plugin-ci', 'jwt');
const tmpFolder = 'tmp';
class Jwt extends command_1.SfdxCommand {
    async run() {
        if (!fs.existsSync(path.join(path.resolve(this.flags.output)))) {
            this.ux.log(messages.getMessage('folderDoNotExist', [this.flags.output]));
            return null;
        }
        fse.ensureDirSync(tmpFolder);
        try {
            child_process_1.execSync(`openssl genrsa -des3 -passout pass:x -out ${path.join(tmpFolder, 'server.pass.key')} 2048 2>/dev/null`);
            child_process_1.execSync(`openssl rsa -passin pass:x -in ${path.join(tmpFolder, 'server.pass.key')} -out ${path.join(tmpFolder, 'server.key')}  2>/dev/null`);
            child_process_1.execSync(`openssl req -new -key ${path.join(tmpFolder, 'server.key')} -out ${path.join(tmpFolder, 'server.csr')} -subj "/C=FR/ST=FRANCE/L=PARIS/O=sfdx/OU=sfdx:auth:jwt/CN=jwt/emailAddress=sfdx@jwt.auth"  2>/dev/null`);
            child_process_1.execSync(`openssl x509 -req -sha256 -days 365 -in ${path.join(tmpFolder, 'server.csr')} -signkey ${path.join(tmpFolder, 'server.key')} -out ${path.join(this.flags.output, this.flags.env + '.crt')}  2>/dev/null`);
            child_process_1.execSync(`openssl aes-256-cbc -salt -e -in ${path.join(tmpFolder, 'server.key')} -out ${path.join(this.flags.output, this.flags.env + '_server.key.enc')} -pass pass:${this.flags.password}  2>/dev/null`);
        }
        catch (ex) {
            throw new core_1.SfdxError(messages.getMessage('errorKeyGeneration'));
        }
        fse.removeSync(tmpFolder);
        this.ux.log(messages.getMessage('successCopy', [`${this.flags.env}_server.key.enc`, path.resolve(this.flags.output)]));
        this.ux.log(messages.getMessage('successCopy', [`${this.flags.env}.crt`, path.resolve(this.flags.output)]));
        return null;
    }
}
exports.default = Jwt;
Jwt.description = messages.getMessage('command');
Jwt.flagsConfig = {
    output: command_1.flags.directory({ char: 'o', description: messages.getMessage('outputFlag'), default: './' }),
    password: command_1.flags.string({ char: 'p', description: messages.getMessage('passwordFlag'), required: true }),
    env: command_1.flags.string({ char: 'e', description: messages.getMessage('envFlag'), default: 'env' }),
    verbose: command_1.flags.builtin()
};
Jwt.requiresProject = false;
//# sourceMappingURL=jwt.js.map